/*====================================================================
                Part-Tracking Schema                        03.03.2003 
======================================================================*/

spool patr_cr;
DROP   TABLE stmeld;
DROP   TABLE stoerkat;
DROP   TABLE fehler;
DROP   TABLE messwert;
DROP   TABLE einbau;
DROP   TABLE aktivitaet;
DROP   TABLE fehlkat;
DROP   TABLE sollwert;
DROP   TABLE tzuord;
DROP   TABLE tcharge;
DROP   TABLE produkt;
DROP   TABLE station;
DROP   TABLE line;


/*--------------------------------------------------------------------
** line         Montagelinie
  --------------------------------------------------------------------*/
CREATE TABLE line
(
line_id         NUMBER(10) NOT NULL ,
line            VARCHAR2(20) NOT NULL ,
name            VARCHAR2(60) ,
last_imp        DATE ,
last_tch        DATE ,
note_io         NUMBER(3),
CONSTRAINT line_pk
           PRIMARY KEY (line_id) ,
CONSTRAINT line_ui01
           UNIQUE (line)
)
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL          10 K
                               NEXT             10 K
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE       0  );
 
START default_synonym line;
START default_grant line;

/*--------------------------------------------------------------------
** station      Bearbeitungsstationen der Linien
  --------------------------------------------------------------------*/
CREATE TABLE station
(
line_id         NUMBER(10) NOT NULL ,
sta_id          NUMBER(10) NOT NULL ,
modul           VARCHAR2(20) NOT NULL ,
pos             VARCHAR2(20) ,
name            VARCHAR2(60) ,
CONSTRAINT station_pk
           PRIMARY KEY (line_id, sta_id) ,
CONSTRAINT station_ui01
           UNIQUE (line_id, modul, pos) ,
CONSTRAINT station_fk01
           FOREIGN KEY (line_id)
	   REFERENCES line(line_id)
)
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL          20 K
                               NEXT             20 K
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE       0  );
 
START default_synonym station;
START default_grant station;

/*--------------------------------------------------------------------
** produkt      Produkt-Typen (Endprodukte)
  --------------------------------------------------------------------*/
CREATE TABLE produkt
(
line_id         NUMBER(10) NOT NULL ,
tpr_id          NUMBER(10) NOT NULL ,
teile_nr        VARCHAR2(20) NOT NULL ,
aestand         VARCHAR2(15) ,
name            VARCHAR2(60) ,
matnr           VARCHAR2(18) ,
CONSTRAINT produkt_pk
           PRIMARY KEY (line_id, tpr_id) ,
CONSTRAINT produkt_ui01
           UNIQUE (teile_nr, aestand, line_id) ,
CONSTRAINT produkt_fk01
           FOREIGN KEY (line_id)
	   REFERENCES line(line_id)
)
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL          20 K
                               NEXT             20 K
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE       0  );
 
START default_synonym produkt;
START default_grant produkt;

/*--------------------------------------------------------------------
** tcharge      dokumentationspflichtige Teile (tracked parts)
  --------------------------------------------------------------------*/
CREATE TABLE tcharge
(
line_id         NUMBER(10) NOT NULL ,
tch_id          NUMBER(10) NOT NULL ,
sta_id          NUMBER(10) NOT NULL ,
teile_nr        VARCHAR2(20) NOT NULL ,
name            VARCHAR2(60) ,
ident           VARCHAR2(20) ,
CONSTRAINT tcharge_pk
           PRIMARY KEY (line_id, tch_id) ,
CONSTRAINT tcharge_ui01
           UNIQUE (line_id, teile_nr, sta_id, tch_id) ,
CONSTRAINT tcharge_fk01
           FOREIGN KEY (line_id, sta_id)
	   REFERENCES station(line_id, sta_id)
)
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL          40 K
                               NEXT             40 K
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE       0  );
 
START default_synonym tcharge;
START default_grant tcharge;

/*--------------------------------------------------------------------
** tzuord       Teilezuordnung (Charge) zu Produkt            
  --------------------------------------------------------------------*/
CREATE TABLE tzuord
(
line_id         NUMBER(10) NOT NULL ,
tpr_id          NUMBER(10) NOT NULL ,
tch_id          NUMBER(10) NOT NULL ,
CONSTRAINT tzuord_pk
           PRIMARY KEY (line_id, tpr_id, tch_id) ,
CONSTRAINT tzuord_fk01
           FOREIGN KEY (line_id, tpr_id)
	   REFERENCES produkt(line_id, tpr_id) ,
CONSTRAINT tzuord_fk02
           FOREIGN KEY (line_id, tch_id)
	   REFERENCES tcharge(line_id, tch_id)
)
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL          40 K
                               NEXT             40 K
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE       0  );
 
START default_synonym tzuord;
START default_grant tzuord;

/*--------------------------------------------------------------------
** sollwert     Merkmals-Spezifikation
  --------------------------------------------------------------------*/
CREATE TABLE sollwert
(
line_id         NUMBER(10) NOT NULL ,
sol_id          NUMBER(10) NOT NULL ,
sta_id          NUMBER(10) NOT NULL ,
tpr_id          NUMBER(10) NOT NULL ,
mmname          VARCHAR2(20) NOT NULL ,
meh             VARCHAR2(10) ,
tol_u           NUMBER(12,6) ,
tol_o           NUMBER(12,6) ,
nennm           NUMBER(12,6) ,
aldatum         DATE ,
alname          VARCHAR2(20) ,
aedatum         DATE ,
aename          VARCHAR2(20) ,
position        VARCHAR2(10) ,
text            VARCHAR2(60) ,
CONSTRAINT sollwert_pk
           PRIMARY KEY (line_id, sol_id) ,
CONSTRAINT sollwert_ui01
           UNIQUE (line_id, tpr_id, sta_id, mmname, sol_id) ,
CONSTRAINT sollwert_ui02
           UNIQUE (line_id, sta_id, mmname, sol_id) ,
CONSTRAINT sollwert_ui03
           UNIQUE (line_id, tpr_id, mmname, sol_id) ,
CONSTRAINT sollwert_ui04
           UNIQUE (line_id, mmname, sol_id) ,
CONSTRAINT sollwert_fk01
           FOREIGN KEY (line_id, sta_id)
	   REFERENCES station(line_id, sta_id) ,
CONSTRAINT sollwert_fk02
           FOREIGN KEY (line_id, tpr_id)
	   REFERENCES produkt(line_id, tpr_id)
)
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL          50 K
                               NEXT             50 K
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE       0  );
 
START default_synonym sollwert;
START default_grant sollwert;

/*--------------------------------------------------------------------
** fehlkat      Katalog fuer Fehlertexte
  --------------------------------------------------------------------*/
CREATE TABLE fehlkat
(
line_id         NUMBER(10) NOT NULL ,
fehl_id         NUMBER(10) NOT NULL ,
fehltext        VARCHAR2(60) NOT NULL ,
fehlcode        NUMBER(10) ,
CONSTRAINT fehlkat_pk
           PRIMARY KEY (line_id, fehl_id) ,
CONSTRAINT fehlkat_fk01
           FOREIGN KEY (line_id)
	   REFERENCES line(line_id)
)
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL          40 K
                               NEXT             40 K
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE       0  );
 
START default_synonym fehlkat;
START default_grant fehlkat;


/*--------------------------------------------------------------------
** aktivitaet   Mess- / Verbau - Aktivitaet
  --------------------------------------------------------------------*/
CREATE TABLE aktivitaet
(
line_id         NUMBER(10) NOT NULL ,
akt_id          NUMBER(10) NOT NULL ,
sta_id          NUMBER(10) NOT NULL ,
tpr_id          NUMBER(10) NOT NULL ,
sernr           VARCHAR2(20) NOT NULL ,
aldatum         DATE ,
alname          VARCHAR2(20) ,
text            VARCHAR2(60) ,
ges_note        NUMBER(3) ,
intz_id         NUMBER(10) ,
moby_nr         NUMBER(10) ,
CONSTRAINT aktivitaet_pk
           PRIMARY KEY (line_id, akt_id) ,
CONSTRAINT aktivitaet_ui01
           UNIQUE (line_id, sta_id, aldatum, akt_id) ,
CONSTRAINT aktivitaet_ui02
           UNIQUE (line_id, tpr_id, aldatum, akt_id) ,
CONSTRAINT aktivitaet_ui03
           UNIQUE (line_id, aldatum, akt_id) ,
CONSTRAINT aktivitaet_ui04
           UNIQUE (line_id, sernr, aldatum, akt_id) ,
CONSTRAINT aktivitaet_fk01
           FOREIGN KEY (line_id, sta_id)
	   REFERENCES station(line_id, sta_id) ,
CONSTRAINT aktivitaet_fk02
           FOREIGN KEY (line_id, tpr_id)
	   REFERENCES produkt(line_id, tpr_id)
)
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL          20 M
                               NEXT              4 M
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE       0  );
 
START default_synonym aktivitaet;
START default_grant aktivitaet;

/*--------------------------------------------------------------------
** einbau       Einbau - Aktivitaet
  --------------------------------------------------------------------*/
CREATE TABLE einbau
(
line_id         NUMBER(10) NOT NULL ,
akt_id          NUMBER(10) NOT NULL ,
tch_id          NUMBER(10) NOT NULL ,
name            VARCHAR2(20) NOT NULL ,
CONSTRAINT einbau_pk
           PRIMARY KEY (line_id, tch_id, akt_id) ,
CONSTRAINT einbau_fk01
           FOREIGN KEY (line_id, tch_id)
	   REFERENCES tcharge(line_id, tch_id) ,
CONSTRAINT einbau_fk02
           FOREIGN KEY (line_id, akt_id)
	   REFERENCES aktivitaet(line_id, akt_id)
)
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL          20 M
                               NEXT              4 M
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE       0  );
 
START default_synonym einbau;
START default_grant einbau;

/*--------------------------------------------------------------------
** messwert     Messdaten je Merkmal und Aktivitaet
  --------------------------------------------------------------------*/
CREATE TABLE messwert
(
line_id         NUMBER(10) NOT NULL ,
akt_id          NUMBER(10) NOT NULL ,
sol_id          NUMBER(10) NOT NULL ,
wertn           NUMBER(14,6) ,
wertx           VARCHAR2(20) ,
text            VARCHAR2(60) ,
CONSTRAINT messwert_pk
           PRIMARY KEY (line_id, sol_id, akt_id) ,
CONSTRAINT messwert_fk01
           FOREIGN KEY (line_id, sol_id)
	   REFERENCES sollwert(line_id, sol_id) ,
CONSTRAINT messwert_fk02
           FOREIGN KEY (line_id, akt_id)
	   REFERENCES aktivitaet(line_id, akt_id)
)
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL          40 M
                               NEXT             10 M
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE       0  );
 
START default_synonym messwert;
START default_grant messwert;

/*--------------------------------------------------------------------
** fehler       Fehler je Aktivitaet
  --------------------------------------------------------------------*/
CREATE TABLE fehler
(
line_id         NUMBER(10) NOT NULL ,
akt_id          NUMBER(10) NOT NULL ,
fehl_id         NUMBER(10) NOT NULL ,
text            VARCHAR2(60) ,
CONSTRAINT fehler_pk
           PRIMARY KEY (line_id, akt_id, fehl_id) ,
CONSTRAINT fehler_fk01
           FOREIGN KEY (line_id, fehl_id)
	   REFERENCES fehlkat(line_id, fehl_id) ,
CONSTRAINT fehler_fk02
           FOREIGN KEY (line_id, akt_id)
	   REFERENCES aktivitaet(line_id, akt_id)
)
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL           2 M
                               NEXT              1 M
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE       0  );
 
START default_synonym fehler;
START default_grant fehler;


/*--------------------------------------------------------------------
**               MDE - DATEN
  --------------------------------------------------------------------*/

/*--------------------------------------------------------------------
** stoerkat      Katalog fuer Stoerungstexte
  --------------------------------------------------------------------*/
CREATE TABLE stoerkat
(
line_id         NUMBER(10) NOT NULL ,
stoer_id        NUMBER(10) NOT NULL ,
stoertext       VARCHAR2(60) NOT NULL ,
behebung        VARCHAR2(60) ,
CONSTRAINT stoerkat_pk
           PRIMARY KEY (line_id, stoer_id) ,
CONSTRAINT stoerkat_fk01
           FOREIGN KEY (line_id)
	   REFERENCES line(line_id)
)
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL          40 K
                               NEXT             40 K
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE       0  );
 
START default_synonym stoerkat;
START default_grant stoerkat;


/*--------------------------------------------------------------------
** stmeld        Stoermeldungen
  --------------------------------------------------------------------*/
CREATE TABLE stmeld
(
line_id         NUMBER(10) NOT NULL ,
stoer_id        NUMBER(10) NOT NULL ,
meld_id         NUMBER(10) NOT NULL ,
aldatum         DATE ,
alname          VARCHAR2(20) ,
anf_end         VARCHAR2(1) ,
CONSTRAINT stmeld_pk
           PRIMARY KEY (line_id, meld_id) ,
CONSTRAINT stmeld_fk01
           FOREIGN KEY (line_id, stoer_id)
	   REFERENCES stoerkat(line_id, stoer_id)
)
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL         200 K
                               NEXT            200 K
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE       0  );
 
START default_synonym stmeld;
START default_grant stmeld;


/*--------------------------------------------------------------------
** err_log      Fehlermeldungen
  --------------------------------------------------------------------*/
 
/*
CREATE TABLE err_log
       (
       source                         VARCHAR2(20),
       datzeit                        DATE,
       errcode                        VARCHAR2(10),
       errmsg                         VARCHAR2(512)
       )
          TABLESPACE PATR
          PCTFREE         20
          PCTUSED         50
          INITRANS         1
          MAXTRANS       255
                     STORAGE ( INITIAL         400 K
                               NEXT            400 K
                               MINEXTENTS        1
                               MAXEXTENTS       99
                               PCTINCREASE      50  );
 
START default_grant err_log;
START default_synonym err_log;
*/

/*--------------------------------------------------------------------
** 
  --------------------------------------------------------------------*/
spool off;
exit;
